@@ -1,7 +1,7 @@
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 ## replacement methods
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 .replacement <- function (x, name, value, case = NULL, left.where = NULL)
 {
@@ -100,7 +100,7 @@
         .sort = sort)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 # replace a single value
 .replace.single <- function (x, name, value, type, udt, case = NULL)
@@ -186,7 +186,7 @@
         .sort = sort)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## when the value is db.Rquery, both x and value
 ## must be derived from a same ancestor.
@@ -197,6 +197,11 @@ setMethod (
     signature (x = "db.obj", value = "db.Rquery"),
     function (x, name, value) {
         if (length(name) != 1) stop("Cannot replace multiple columns")
+        if (is(value, "db.Rquery") && value@.is.agg) {
+            value <- as.numeric(lookat(value))
+            x[[name]] <- value
+            return (x)
+        }
         .replacement(x, name, value)
     },
     valueClass = "db.Rquery")
@@ -238,7 +243,7 @@ setMethod (
     },
     valueClass = "db.Rquery")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 .preprocess.name <- function (x, i)
 {
@@ -253,7 +258,7 @@ setMethod (
     name
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## Similar to the above function, but for [[
 setMethod (
@@ -261,6 +266,23 @@ setMethod (
     signature (x = "db.obj", value = "db.Rquery"),
     function (x, i, j, value) {
         if (length(i) != 1) stop("Cannot replace multiple columns")
+          if (is(value, "db.Rquery") && value@.is.agg) {
+            value <- as.numeric(lookat(value))
+            if (missing(i) && missing(j)) {
+                x[[,]] <- value
+                return (x)
+            }
+            if (missing(i)) {
+                x[[,j]] <- value
+                return (x)
+            }
+            if (missing(j)) {
+                x[[i,]] <- value
+                return (x)
+            }
+            x[[i,j]] <- value
+            return (x)
+        }
         name <- .preprocess.name(x, i)
         .replacement(x, name, value)
     },
@@ -307,8 +329,8 @@ setMethod (
     },
     valueClass = "db.Rquery")
 
-## ------------------------------------------------------------------------
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## the condition expression in case
 .case.condition <- function (x, i)
@@ -331,13 +353,31 @@ setMethod (
     str
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 setMethod (
     "[<-",
     signature (x = "db.obj", value = "db.Rquery"),
     function (x, i, j, value) {
         n <- length(sys.calls()[[1]]) - 1
+        if (is(value, "db.Rquery") && value@.is.agg) {
+            value <- as.numeric(lookat(value))
+            if (missing(i) && missing(j)) {
+                x[,] <- value
+                return (x)
+            }
+            if (missing(i)) {
+                x[,j] <- value
+                return (x)
+            }
+            if (missing(j)) {
+                x[i,] <- value
+                return (x)
+            }
+            x[i,j] <- value
+            return (x)
+        }
+        
         if (length(x@.col.name) == 1 && x@.col.data_type == "array") {
             x <- .expand.array(x)
             if (n == 3)
@@ -347,7 +387,7 @@ setMethod (
                 else if (missing(i)) x[,j] <- value
                 else if (missing(j)) x[i,] <- value
                 else x[i,j] <- value
-            return (rowAgg(x))
+            return (db.array(x))
         }
         
         if (n == 4) {
@@ -367,12 +407,16 @@ setMethod (
                     .replacement(x, names(x[i,j]), value, str, where.str)
             }
         } else if (n == 3) {
-            .replacement(x, names(x[i]), value)
+            if (is(i, "db.Rquery")) {
+                str <- .case.condition(x, i)
+                .replacement(x, names(x[i]), value, str)
+            } else
+                .replacement(x, names(x[i]), value)
         }
     },
     valueClass = "db.Rquery")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 setMethod (
     "[<-",
@@ -389,7 +433,7 @@ setMethod (
                 else if (missing(i)) x[,j] <- value
                 else if (missing(j)) x[i,] <- value
                 else x[i,j] <- value
-            return (rowAgg(x))
+            return (db.array(x))
         }
  
         if (n == 4) {
@@ -418,7 +462,7 @@ setMethod (
     },
     valueClass = "db.Rquery")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 setMethod (
     "[<-",
@@ -434,7 +478,7 @@ setMethod (
                 else if (missing(i)) x[,j] <- value
                 else if (missing(j)) x[i,] <- value
                 else x[i,j] <- value
-            return (rowAgg(x))
+            return (db.array(x))
         }
         if (n == 4) {
             if (missing(i) && missing(j))
@@ -461,7 +505,7 @@ setMethod (
     },
     valueClass = "db.Rquery")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 setMethod (
     "[<-",
@@ -477,7 +521,7 @@ setMethod (
                 else if (missing(i)) x[,j] <- value
                 else if (missing(j)) x[i,] <- value
                 else x[i,j] <- value
-            return (rowAgg(x))
+            return (db.array(x))
         }
         if (n == 4) {
             if (missing(i) && missing(j)) {
@@ -508,7 +552,7 @@ setMethod (
     },
     valueClass = "db.Rquery")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 setMethod (
     "[<-",
@@ -524,7 +568,7 @@ setMethod (
                 else if (missing(i)) x[,j] <- value
                 else if (missing(j)) x[i,] <- value
                 else x[i,j] <- value
-            return (rowAgg(x))
+            return (db.array(x))
         }
         if (n == 4) {
             if (missing(i) && missing(j))
