@@ -6,7 +6,7 @@
     tolower(attr(installed.packages(), "dimnames")[[1]])
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## define local variables
 
@@ -31,4 +31,8 @@
         .localVars$conn.type[[tolower(.supported.connections[i])]] <- integer(0)
 
     packageStartupMessage("\nTo launch the graphical user interface, run the function pivotalr() !")
+
+    ## turn on cbind implementation using cbind2
+    .localVars$pkg.path <- path.package(.this.pkg.name)
+    source(paste0(.localVars$pkg.path, "/auto/enable.cbind2.R"))
 }
