@@ -3,7 +3,7 @@
 
 ## Check arguments of function to make sure that they are legal
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## convert {...} string into an arrayparams$grp.str
 arraydb.to.arrayr <- function (str, type = "double", n = 1)
@@ -25,18 +25,21 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
             res <- rbind(res, rep(NA, n))
             next
         }
-        
-        elm <- regmatches(str[i],
-                          gregexpr("[^,\"\\s\\{\\}]+|\"[^\"]*\"",
-                                   str[i], perl=T))[[1]]
-        if (type == "character")
+
+        if (type == "character") {
+            elm <- regmatches(str[i],
+                              gregexpr("[^,\"\\s\\{\\}]+|\"[^\"]*\"",
+                                       str[i], perl=T))[[1]]
             elm <- as.character(elm)
-        else if (type == "integer")
-            elm <- as.integer(elm)
-        else if (type == "logical")
-            elm <- as.logical(elm)
-        else
-            elm <- as.numeric(elm)
+        } else {
+            elm <- strsplit(gsub("(\\{|\\})", "", str[i]), ",")[[1]]
+            if (type == "integer")
+                elm <- as.integer(elm)
+            else if (type == "logical")
+                elm <- as.logical(elm)
+            else
+                elm <- as.numeric(elm)
+        }
         
         res <- rbind(res, elm)
     }
@@ -44,7 +47,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     res
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 .is.arg.string <- function (arg)
 {
@@ -52,19 +55,20 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
             is.character(arg))
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 .is.conn.id.valid <- function (conn.id)
 {
     return (length(conn.id) != 0 &&
             !is.null(conn.id) &&
-            !is.na(conn.id) && 
+            !is.na(conn.id) &&
+            is(conn.id, "numeric") &&
             conn.id >= 1 &&
             length(.localVars$conn.id) != 0 &&
             conn.id %in% .localVars$conn.id[,1])
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## get the distributed by string
 .get.distributed.by.str <- function(conn.id, distributed.by)
@@ -87,7 +91,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     return (dist.str)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## simply return the most direct answer
 .db.analyze.table.name <- function (name)
@@ -109,7 +113,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
         return (paste("table_name = '", table, "'", sep = ""))
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## Is the object in database a table?
 .is.table.or.view <- function (table, conn.id = 1)
@@ -123,7 +127,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
         return (FALSE)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## Is the object in database a view?
 .is.view <- function (table, conn.id = 1)
@@ -137,7 +141,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
         return (FALSE)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 .unique.string <- function ()
 {
@@ -156,7 +160,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     gsub(rm.str, "\\1", str, perl = TRUE)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## analyze formula
 .analyze.formula <- function (formula, data, fdata = data, refresh = FALSE,
@@ -291,7 +295,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
          data = data)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## R's log is SQL's log(exp(1.), x)
 ## R's log10 is SQL's log
@@ -304,7 +308,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     res
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 .replace.with.quotes <- function (vars, cols)
 {
@@ -332,7 +336,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     vars
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## interactively read an input from the user
 .read.input <- function (msg, expected.answer = c("yes", "y", "no", "n"))
@@ -343,7 +347,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     a
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## set/reset the message level
 ## returns the old message level
@@ -354,7 +358,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     old.level
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## If an independent variable is an array, it needs special treatment
 .is.array <- function (labels, data)
@@ -390,7 +394,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     nlabels
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## replace array in the formula
 .replace.array <- function (fstr, data)
@@ -427,7 +431,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
     fstr
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 
 ## whether two where strings are equivalent
 .eql.where <- function (where1, where2)
